# -*- coding: utf-8 -*-
"""
工具描述配置
包含所有MCP工具的详细描述信息
"""

TOOL_DESCRIPTIONS = {
    "basic_arithmetic": {
        "description": "基础算术运算工具",
        "args": {
            "operation": "运算类型，必选。可选值：'add'(加法), 'subtract'(减法), 'multiply'(乘法), 'divide'(除法), 'power'(幂运算), 'modulo'(取模), 'factorial'(阶乘), 'gcd'(最大公约数), 'lcm'(最小公倍数)",
            "numbers": "数值列表，必选，不能为空。对于加法/乘法：至少1个数值；减法/除法/取模/最大公约数/最小公倍数：至少2个数值；幂运算：恰好2个数值(底数,指数)；阶乘：恰好1个非负整数",
            "precision": "计算精度（小数位数），可选，正整数，默认为None",
            "use_decimal": "是否使用高精度小数计算，可选，布尔值，默认False",
        },
        "returns": "计算结果字典，包含result、operation、inputs等字段",
        "examples": [
            "operation='add', numbers=[1, 2, 3, 4]",
            "operation='power', numbers=[2, 3], precision=5",
            "operation='factorial', numbers=[5]",
        ],
    },
    "mathematical_functions": {
        "description": "数学函数计算工具",
        "args": {
            "function": "函数类型，必选。可选值：'sin'(正弦), 'cos'(余弦), 'tan'(正切), 'asin'(反正弦), 'acos'(反余弦), 'atan'(反正切), 'sinh'(双曲正弦), 'cosh'(双曲余弦), 'tanh'(双曲正切), 'log'(对数), 'log10'(常用对数), 'ln'(自然对数), 'sqrt'(平方根), 'cbrt'(立方根), 'exp'(指数), 'abs'(绝对值), 'ceil'(向上取整), 'floor'(向下取整), 'round'(四舍五入)",
            "value": "输入值，必选，数值类型。对于反三角函数，需要在定义域内",
            "base": "对数的底数，可选，仅用于'log'函数，必须为正数且不等于1，默认为e",
            "precision": "结果精度，可选，正整数，默认为None",
            "angle_unit": "角度单位，可选。可选值：'radians'(弧度,默认), 'degrees'(角度)。仅用于三角函数",
        },
        "returns": "函数计算结果字典",
        "examples": [
            "function='sin', value=1.57, angle_unit='radians'",
            "function='log', value=100, base=10",
            "function='sqrt', value=16",
        ],
    },
    "number_converter": {
        "description": "数值进制转换和格式化工具",
        "args": {
            "number": "输入数值，必选，字符串格式",
            "from_base": "源进制，可选，整数，范围2-36，默认10",
            "to_base": "目标进制，可选，整数，范围2-36，默认10",
            "operation": "操作类型，可选。可选值：'convert'(进制转换,默认), 'format'(格式化), 'scientific'(科学计数法), 'fraction'(分数形式)",
            "precision": "精度控制，可选，非负整数",
        },
        "returns": "转换结果字典",
        "examples": [
            "number='1010', from_base=2, to_base=10",
            "number='255', from_base=10, to_base=16",
            "number='3.14159', operation='scientific', precision=3",
        ],
    },
    "unit_converter": {
        "description": "单位转换工具",
        "args": {
            "value": "输入值，必选，数值类型，必须为正数（温度转换除外）",
            "from_unit": "源单位，必选，字符串，必须是对应单位类型的有效单位",
            "to_unit": "目标单位，必选，字符串，必须是对应单位类型的有效单位",
            "unit_type": "单位类型，必选。可选值：'length'(长度), 'weight'(重量), 'temperature'(温度), 'area'(面积), 'volume'(体积), 'time'(时间), 'speed'(速度), 'energy'(能量)",
        },
        "returns": "转换结果字典",
        "examples": [
            "value=100, from_unit='cm', to_unit='m', unit_type='length'",
            "value=32, from_unit='fahrenheit', to_unit='celsius', unit_type='temperature'",
        ],
    },
    "precision_calculator": {
        "description": "高精度计算工具",
        "args": {
            "numbers": "数值列表，必选，不能为空，至少包含1个数值",
            "operation": "运算类型，必选。可选值：'add'(加法), 'subtract'(减法), 'multiply'(乘法), 'divide'(除法), 'power'(幂运算), 'sqrt'(平方根)",
            "precision_digits": "精度位数，可选，正整数，范围1-100，默认10",
            "rounding_mode": "舍入模式，可选，默认'round_half_up'",
        },
        "returns": "高精度计算结果字典",
        "examples": [
            "numbers=[0.1, 0.2, 0.3], operation='add', precision_digits=20",
            "numbers=[2, 0.5], operation='power', precision_digits=15",
        ],
    },
    "number_properties": {
        "description": "数值属性分析工具",
        "args": {
            "number": "输入数值，必选，整数或浮点数",
            "analysis_type": "分析类型，可选。可选值：'comprehensive'(综合分析,默认), 'prime'(素数判定), 'divisors'(因数分解), 'properties'(基本属性)",
        },
        "returns": "数值属性分析结果字典",
        "examples": [
            "number=12, analysis_type='comprehensive'",
            "number=17, analysis_type='prime'",
        ],
    },
    "matrix_calculator": {
        "description": "综合矩阵计算工具 - 可执行多种矩阵运算",
        "args": {
            "operation": "运算类型。可选项：'basic', 'decomposition', 'eigenvalues', 'svd', 'properties', 'power', 'exponential', 'solve'",
            "matrix_a": "第一个矩阵，以列表的列表形式提供。示例: [[1, 2], [3, 4]] 表示一个2x2矩阵",
            "matrix_b": "第二个矩阵（某些运算需要）",
            "method": "当 'operation' 是 'basic', 'decomposition', 或 'properties' 时，需要此参数来指定具体方法",
            "power": "当 'operation' 是 'power' 时，指定矩阵的幂次",
            "property_type": "当 'operation' 是 'properties' 且 'method' 是 'norm' 时，用此参数指定范数类型",
        },
        "returns": "计算结果字典",
        "examples": [
            "operation='basic', method='add', matrix_a=[[1,2],[3,4]], matrix_b=[[5,6],[7,8]]",
            "operation='basic', method='determinant', matrix_a=[[1,2],[3,4]]",
            "operation='properties', method='norm', property_type='l1', matrix_a=[[1,-2],[3,4]]",
        ],
    },
    "statistics_analyzer": {
        "description": "综合统计分析工具 - 可执行多种统计分析",
        "args": {
            "data1": "第一组数据，必选，不能为空。必须是数值列表。示例: [1.2, 2.3, 3.1, 4.5, 2.8]",
            "analysis_type": "分析类型，必选。可选值: 'descriptive'(描述性统计：均值、中位数、标准差等), 'tests'(统计检验), 'distribution'(分布分析), 'confidence_interval'(置信区间计算)",
            "data2": "第二组数据，可选，用于双样本检验或相关性分析。必须与data1长度相同（相关性分析）。示例: [2.1, 3.2, 4.1, 5.3, 3.7]",
            "test_type": "检验类型，当analysis_type='tests'时使用。可选值: 'normality'(正态性检验), 'hypothesis'(假设检验), 'correlation'(相关性分析)。当analysis_type='distribution'时使用: 'fitting'(分布拟合), 'percentiles'(分位数), 'outliers'(异常值检测)",
            "hypothesis_test_type": "具体假设检验方法，当test_type='hypothesis'时使用。可选值: 'one_sample_t'(单样本t检验), 'two_sample_t'(双样本t检验), 'ttest_ind'(独立样本t检验), 'paired_t'(配对t检验), 'mannwhitneyu'(Mann-Whitney U检验), 'wilcoxon'(Wilcoxon检验)",
            "confidence": "置信水平，可选，范围(0,1)，默认0.95（即95%置信水平）",
            "distribution_type": "分布类型，可选，预留参数",
        },
        "returns": "统计分析结果字典",
        "examples": [
            "data1=[1, 2, 3, 4, 5], analysis_type='descriptive'",
            "data1=[1.2, 2.1, 3.0, 2.8, 3.5], analysis_type='tests', test_type='normality'",
            "data1=[12, 15, 18, 20, 22, 25, 28, 30, 32, 35], analysis_type='distribution', test_type='outliers'",
            "data1=[23, 25, 28, 30, 32, 35, 37, 40], data2=[20, 22, 24, 26, 28, 30, 32, 34], analysis_type='tests', test_type='hypothesis', hypothesis_test_type='ttest_ind'",
        ],
    },
    "calculus_engine": {
        "description": "综合微积分计算工具 - 支持导数、积分、极限等运算",
        "args": {
            "expression": "数学表达式字符串，必选。必须是有效的数学表达式。示例: 'x**2 + 3*x', 'sin(x)', 'x**4 + 3*x**2'",
            "operation": "运算类型，必选。可选值：'derivative'(求导数), 'integral'(求积分), 'limit'(求极限), 'series'(级数展开), 'critical_points'(寻找临界点), 'partial'(偏导数，需要variables参数), 'gradient'(梯度，需要variables参数), 'taylor'(泰勒展开), 'arc_length'(弧长计算)",
            "variable": "主变量名，可选，默认为'x'。必须是表达式中存在的变量",
            "variables": "多变量列表，用于偏导数、梯度等操作时必选。示例: ['x', 'y'] 用于多变量函数",
            "limits": "积分限或其他范围，可选。示例: [0, 1] 表示从0到1的定积分",
            "point": "计算点，可选，用于在特定点求导数值或极限。示例: 2.0 表示在x=2处计算",
            "points": "多个计算点，可选，用于梯度计算。示例: [1, 1] 表示在点(1,1)处计算梯度",
            "order": "导数阶数或泰勒级数项数，可选，默认为1。对于导数：1表示一阶导数，2表示二阶导数；对于泰勒级数：表示展开项数",
            "method": "计算方法，可选，默认'quad'。用于数值积分",
            "mode": "计算模式，可选。可选值: 'symbolic'(符号计算，默认), 'numerical'(数值计算)",
        },
        "returns": "微积分计算结果字典",
        "examples": [
            "expression='x**3 + 2*x**2 - 5*x + 3', operation='derivative', variable='x'",
            "expression='x**3', operation='derivative', variable='x', order=2",
            "expression='x**2', operation='integral', variable='x', limits=[0, 2]",
            "expression='x**2 + y**2', operation='gradient', variables=['x', 'y'], points=[1, 1]",
        ],
    },
    "optimization_suite": {
        "description": "综合优化计算工具 - 支持多种优化问题的求解，包括无约束优化、约束优化、全局优化等",
        "args": {
            "objective_function": "目标函数的字符串表达式，必选。必须是有效的数学表达式。示例: 'x**2 + y**2', '2*x**2 + 3*y**2', 'sin(x) + cos(y)'",
            "variables": "变量列表，必选，不能为空。示例: ['x', 'y'] 表示双变量优化，['x'] 表示单变量优化",
            "operation": "操作类型，可选。可选值：'minimize'(最小化，默认), 'maximize'(最大化), 'constrained'(约束优化), 'global'(全局优化), 'root_finding'(求根), 'linear_programming'(线性规划), 'least_squares'(最小二乘)",
            "method": "计算方法，可选，默认'auto'自动选择。可选值：'auto'(自动), 'symbolic'(符号计算), 'BFGS'(拟牛顿法), 'SLSQP'(序列二次规划), 'differential_evolution'(差分进化), 'Nelder-Mead'(单纯形法)",
            "initial_guess": "初始猜测值列表，可选。数量必须与variables长度一致。如果不提供，系统会自动生成。示例: [1.0, 1.0] 对应变量 ['x', 'y'] 的初始值",
            "bounds": "变量边界列表，可选，用于约束变量范围。格式: [(min1, max1), (min2, max2), ...]，数量必须与variables长度一致。示例: [(0, 10), (-5, 5)] 表示 x∈[0,10], y∈[-5,5]。对于'global'操作是必选的",
            "constraints": "约束条件列表，仅用于 'constrained' 操作时必选，其他操作时可选。格式: [{'type': 'eq'/'ineq', 'fun': '约束表达式字符串'}]。'eq'表示等式约束(表达式=0)，'ineq'表示不等式约束(表达式>=0)。不能为空列表",
            "equation": "方程字符串，仅用于 'root_finding' 操作，可选。如不提供则使用objective_function",
        },
        "returns": "优化计算结果字典，包含最优解、目标函数值、收敛信息等",
        "examples": [
            "# 无约束最小化: objective_function='x**2 + y**2', variables=['x', 'y'], operation='minimize'",
            "# 约束优化: objective_function='2*x**2 + 3*y**2', variables=['x', 'y'], operation='constrained', constraints=[{'type': 'ineq', 'fun': 'x + y - 1'}]",
            "# 带初始值的优化: objective_function='x**2 + y**2', variables=['x', 'y'], operation='minimize', initial_guess=[1.0, 1.0]",
            "# 有界优化: objective_function='x**2 + y**2', variables=['x', 'y'], operation='minimize', bounds=[(-2, 2), (-2, 2)]",
            "# 等式约束: objective_function='x**2 + y**2', variables=['x', 'y'], operation='constrained', constraints=[{'type': 'eq', 'fun': 'x + y - 1'}]",
            "# 全局优化: objective_function='sin(x) + cos(y)', variables=['x', 'y'], operation='global', bounds=[(-10, 10), (-10, 10)]",
        ],
    },
    "regression_modeler": {
        "description": "综合回归建模工具",
        "args": {
            "operation": "操作类型。'fit' (默认): 拟合回归模型, 'residual_analysis': 进行残差分析, 'model_comparison': 比较多个模型",
            "x_data": "自变量数据矩阵。用于 'fit' 操作。格式: [[x1_1, x1_2, ...], [x2_1, x2_2, ...], ...]",
            "y_data": "因变量数据。用于 'fit' 操作。示例: [2.1, 3.9, 6.2, 8.1]",
            "model_type": "模型类型。用于 'fit' 操作。'linear': 线性回归, 'polynomial': 多项式回归（仅支持单变量）, 'ridge': 岭回归, 'lasso': Lasso回归, 'elastic_net': 弹性网络回归, 'logistic': 逻辑回归",
            "degree": "多项式次数（用于多项式回归）",
            "alpha": "正则化参数（用于正则化回归）",
            "l1_ratio": "L1正则化比例（用于ElasticNet）",
            "cv_folds": "交叉验证折数",
            "test_size": "测试集比例",
            "y_true": "真实值（用于 'residual_analysis'）",
            "y_pred": "预测值（用于 'residual_analysis'）",
            "models_results": "模型结果列表（用于 'model_comparison'）",
        },
        "returns": "回归建模或分析结果字典",
        "examples": [
            "operation='fit', x_data=[[1], [2], [3]], y_data=[2, 4, 6], model_type='linear'",
            "operation='residual_analysis', y_true=[2, 4, 6], y_pred=[2.1, 3.9, 6.1]",
        ],
    },
    "expression_evaluator": {
        "description": "数学表达式求值和简化工具",
        "args": {
            "expression": "数学表达式字符串",
            "variables": "变量值字典",
            "mode": "计算模式 ('evaluate', 'simplify', 'expand', 'factor')",
            "output_format": "输出格式 ('decimal', 'fraction', 'latex')",
        },
        "returns": "表达式计算结果",
        "examples": [
            "expression='x**2 + 2*x + 1', mode='factor'",
            "expression='2*x + 3', variables={'x': 5}, mode='evaluate'",
        ],
    },
    "create_and_save_chart": {
        "description": "综合图表绘制和保存工具 - 支持多种图表类型，直接保存到指定路径",
        "args": {
            "chart_type": "图表类型。支持以下选项：'bar': 柱状图，需要 data 和 labels（可选）, 'pie': 饼图，需要 data 和 labels（可选）, 'line': 线图，需要 x_data 和 y_data, 'scatter': 散点图，需要 x_data 和 y_data, 'histogram': 直方图，需要 data, 'box': 箱线图，需要 data 或 matrix_data, 'heatmap': 热力图，需要 matrix_data, 'correlation_matrix': 相关性矩阵图，需要 matrix_data, 'multi_series_line': 多系列线图，需要 x_data 和 y_data_series",
            "data": "单组数据列表。用于 bar, pie, histogram, box 图表。示例: [10, 20, 30, 40]",
            "x_data": "X轴数据列表。用于 line, scatter, multi_series_line 图表。示例: [1, 2, 3, 4]",
            "y_data": "Y轴数据列表。用于 line, scatter 图表。示例: [10, 20, 15, 25]",
            "y_data_series": "多系列Y轴数据。用于 multi_series_line 图表。格式: [[series1_y_values], [series2_y_values], ...]",
            "series_labels": "多系列图的标签列表。与 y_data_series 配合使用。示例: ['平方', '立方']",
            "matrix_data": "矩阵数据。用于 heatmap, correlation_matrix, 多组box图。格式: [[row1], [row2], ...]",
            "labels": "数据标签列表。用于 bar, pie 图表的标签。示例: ['A', 'B', 'C', 'D']",
            "title": "图表标题",
            "xlabel": "X轴标签",
            "ylabel": "Y轴标签",
            "filename": "保存文件名（不含扩展名）。如果不提供，将自动生成。示例: 'my_chart' 将保存为 'my_chart.png'",
        },
        "returns": "包含保存路径和图表信息的结果字典",
        "examples": [
            "chart_type='bar', data=[10, 20, 30], labels=['A', 'B', 'C']",
            "chart_type='scatter', x_data=[1, 2, 3], y_data=[2, 4, 6]",
            "chart_type='multi_series_line', x_data=[1, 2, 3], y_data_series=[[1, 4, 9], [1, 8, 27]], series_labels=['平方', '立方']",
        ],
    },
    "plot_function_curve": {
        "description": "函数图像绘制工具 - 绘制数学函数的曲线图并保存到文件（仅保存文件，不返回图像数据）",
        "args": {
            "function_expression": "函数表达式字符串，必选。必须是有效的数学表达式。示例: 'x**2', 'sin(x)', 'exp(-x**2)', 'x**3 - 2*x + 1'",
            "variable": "变量名，可选，默认为'x'。必须是表达式中存在的变量",
            "x_range": "X轴范围，可选，格式为(最小值, 最大值)，默认(-10, 10)。示例: (-5, 5), (0, 10)",
            "num_points": "绘图点数，可选，正整数，默认1000。点数越多图像越平滑但计算时间更长",
            "title": "图表标题，可选，默认'函数图像'",
            "xlabel": "X轴标签，可选，默认'X轴'",
            "ylabel": "Y轴标签，可选，默认'Y轴'",
            "filename": "保存文件名（不含扩展名），可选。如果不提供，将基于函数表达式自动生成",
            "format": "图像格式，可选，默认'png'。支持png、jpg、pdf等",
            "figsize": "图像大小 (宽度, 高度)，可选，默认(10, 6)",
            "dpi": "图像分辨率，可选，正整数，默认300",
            "color": "线条颜色，可选，默认'blue'",
            "line_width": "线条宽度，可选，正数，默认2.0",
            "grid": "是否显示网格，可选，布尔值，默认True",
            "derivative_order": "是否同时绘制导数曲线，可选，正整数，指定导数阶数",
            "show_critical_points": "是否标记临界点，可选，布尔值，默认False",
            "show_equation": "是否在图上显示函数方程，可选，布尔值，默认True",
        },
        "returns": "包含保存路径、文件名和图表信息的结果字典，不包含图像数据以节省token",
        "examples": [
            "function_expression='x**2', x_range=(-3, 3)",
            "function_expression='sin(x)', x_range=(0, 6.28), show_critical_points=True",
            "function_expression='x**3 - 2*x', x_range=(-2, 2), derivative_order=1",
        ],
    },
    "cleanup_resources": {
        "description": "清理计算资源和临时文件",
        "args": {},
        "returns": "清理结果信息",
        "examples": [],
    },
}
